#!/usr/bin/env python3
# -*- coding: utf-8 -*-


"""
@author: laplaciannin102(Kosuke Asada)
@date: 2022/10/10

version management script.

@history:
    2021/10/13:
        初期版作成．

    2022/10/10:
        v0.0.3
"""



# --------------------------------------------------------------------------------
# Constants
# --------------------------------------------------------------------------------

# version
__version__ = '0.0.3'

